@@ -24,37 +24,18 @@ describe 'cinder::api' do
       )}
 
       it 'should configure cinder api correctly' do
-        is_expected.to contain_cinder_config('DEFAULT/osapi_volume_listen').with(
-         :value => '0.0.0.0'
-        )
-        is_expected.to contain_cinder_config('DEFAULT/osapi_volume_workers').with(
-         :value => '8'
-        )
-        # nova_catalog_info has been deprecated
-        is_expected.not_to contain_cinder_config('DEFAULT/nova_catalog_info')
-        is_expected.to contain_cinder_config('DEFAULT/default_volume_type').with(
-         :value => '<SERVICE DEFAULT>'
-        )
-        is_expected.to contain_cinder_config('DEFAULT/public_endpoint').with(
-         :value => '<SERVICE DEFAULT>'
-        )
-        is_expected.to contain_cinder_config('DEFAULT/osapi_volume_base_URL').with(
-         :value => '<SERVICE DEFAULT>'
-        )
-        is_expected.to contain_cinder_config('DEFAULT/osapi_max_limit').with(
-         :value => '<SERVICE DEFAULT>'
-        )
-        is_expected.to contain_cinder_config('DEFAULT/os_region_name').with(
-         :value => '<SERVICE DEFAULT>'
-        )
-        is_expected.to contain_cinder_config('DEFAULT/auth_strategy').with(
-         :value => 'keystone'
-        )
-
-        is_expected.to contain_cinder_config('key_manager/backend').with_value('cinder.keymgr.conf_key_mgr.ConfKeyManager')
+        is_expected.to contain_cinder_config('DEFAULT/osapi_volume_listen').with_value('0.0.0.0')
+        is_expected.to contain_cinder_config('DEFAULT/osapi_volume_workers').with_value('8')
+        is_expected.to contain_cinder_config('DEFAULT/default_volume_type').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('DEFAULT/public_endpoint').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('DEFAULT/osapi_volume_base_URL').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('DEFAULT/osapi_max_limit').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('DEFAULT/auth_strategy').with_value('keystone')
+        is_expected.to contain_cinder_config('key_manager/backend').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/osapi_volume_listen_port').with('value' => '<SERVICE DEFAULT>')
+
         is_expected.to contain_oslo__middleware('cinder_config').with(
           :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
           :max_request_body_size        => '<SERVICE DEFAULT>',
@@ -62,37 +43,6 @@ describe 'cinder::api' do
       end
     end
 
-    context 'with deprecated parameters' do
-      let :params do
-        req_params.merge({
-          'nova_catalog_info'           => 'compute:nova:publicURL',
-          'os_privileged_user_name'     => 'admin',
-          'os_privileged_user_password' => 'password',
-          'os_privileged_user_tenant'   => 'admin',
-          'os_privileged_user_auth_url' => 'http://localhost:8080',
-        })
-      end
-      it 'should not add them to the config' do
-        is_expected.not_to contain_cinder_config('DEFAULT/nova_catalog_info')
-        is_expected.not_to contain_cinder_config('DEFAULT/os_privileged_user_name')
-        is_expected.not_to contain_cinder_config('DEFAULT/os_privileged_user_password')
-        is_expected.not_to contain_cinder_config('DEFAULT/os_privileged_user_tenant')
-        is_expected.not_to contain_cinder_config('DEFAULT/os_privileged_user_auth_url')
-
-      end
-    end
-
-    context 'with a custom region for nova' do
-      let :params do
-        req_params.merge({'os_region_name' => 'MyRegion'})
-      end
-      it 'should configure the region for nova' do
-        is_expected.to contain_cinder_config('DEFAULT/os_region_name').with(
-          :value => 'MyRegion'
-        )
-      end
-    end
-
     context 'with a customized port' do
       let :params do
         req_params.merge({'osapi_volume_listen_port' => 9999})
@@ -281,29 +231,18 @@ describe 'cinder::api' do
     context 'with barbican parameters' do
       let :params do
         req_params.merge!({
-          :keymgr_backend             => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
+          :keymgr_backend             => 'barbican',
           :keymgr_encryption_api_url  => 'https://localhost:9311/v1',
           :keymgr_encryption_auth_url => 'https://localhost:5000/v3',
         })
       end
       it 'should set keymgr parameters' do
-        is_expected.to contain_cinder_config('key_manager/backend').with_value('castellan.key_manager.barbican_key_manager.BarbicanKeyManager')
+        is_expected.to contain_cinder_config('key_manager/backend').with_value('barbican')
         is_expected.to contain_cinder_config('barbican/barbican_endpoint').with_value('https://localhost:9311/v1')
         is_expected.to contain_cinder_config('barbican/auth_endpoint').with_value('https://localhost:5000/v3')
       end
     end
 
-    context 'with barbican deprecated parameters' do
-      let :params do
-        req_params.merge!({
-          :keymgr_api_class           => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
-        })
-      end
-      it 'should set keymgr parameter' do
-        is_expected.to contain_cinder_config('key_manager/backend').with_value('castellan.key_manager.barbican_key_manager.BarbicanKeyManager')
-      end
-    end
-
   end
 
   on_supported_os({
