@@ -1,8 +1,7 @@
 require 'spec_helper'
 
 describe 'cinder::wsgi::apache' do
-
-  shared_examples_for 'apache serving cinder with mod_wsgi' do
+  shared_examples 'apache serving cinder with mod_wsgi' do
     context 'with default parameters' do
       it { is_expected.to contain_class('cinder::params') }
       it { is_expected.to contain_class('apache') }
@@ -35,6 +34,7 @@ describe 'cinder::wsgi::apache' do
           :bind_host                   => '10.42.51.1',
           :port                        => 12345,
           :ssl                         => false,
+          :vhost_custom_fragment       => 'Timeout 99',
           :wsgi_process_display_name   => 'cinder-api',
           :workers                     => 37,
           :custom_wsgi_process_options => {
@@ -58,6 +58,7 @@ describe 'cinder::wsgi::apache' do
         :ssl                       => false,
         :threads                   => 1,
         :user                      => 'cinder',
+        :vhost_custom_fragment     => 'Timeout 99',
         :workers                   => 37,
         :wsgi_daemon_process       => 'cinder-api',
         :wsgi_process_display_name => 'cinder-api',
